//
//  RTVManager.h
//  RTV
//
//  Created by Michael Rothwell on Sun Jan 18 2004.
//  Copyright (c) 2004 Michael Rothwell. All rights reserved.
//

#import <Foundation/Foundation.h>

#import "RTV.h"
#import "RTVShow.h"
#import "UPNP_SSDP.h"

#include <stdio.h>
#include <string.h>
#include <arpa/inet.h>
#include <sys/types.h>
#include <sys/time.h>
#include <sys/socket.h>
#include <netinet/in.h>
#include <sys/select.h>
#include <unistd.h>

#define	UPNPADDR	"239.255.255.250"
#define	UPNPPORT	1900

@interface RTVManager : NSObject 
{
    // for UPnP thread
    int m_UPNP_running;
    
    // threadless SSDP listener
    UPNP_SSDP *upnp_listener;
    
    // list of RTVs
    NSMutableArray *m_RTVs;
    
    // list of sort-orders
    NSMutableArray *m_SortOrders;
    NSMutableDictionary *m_SortState;
    
    // currently selected RTV
    RTV *m_Selected;
    
    //list of shows
    NSMutableArray *m_Shows;
    
    // for thread safety
    NSRecursiveLock *m_lock;
    
    // cache dir
    NSString *m_cacheDir;
    
    // timer
    NSTimer *m_RefreshTimer;
}
-(id)init;
-(id)RTVfromIPAddress:(NSString *)IPAddress;

-(NSArray *)allRTVs;

-(void)start_upnp;
-(void)stop_upnp;

- (int) send_rtv_probe:(int)s;
- (char *)parseUPNP:(char *)buffer;
- (int)thread_upnpDiscover:(id)owner;

-(void)RTVWithHostName:(NSString *)hostname;

-(NSMutableArray *)allShows;
-(void) rebuildAllShows;

-(void)reSort;
-(void)sortBy:(NSString *)sortField order:(int)order;
-(void)toggleSortState:(NSString *)column;

-(void)select:(RTV *)rtv;
-(RTV *)selected;

-(void)deleteRTV:(RTV *)rtv;

-(void)saveGuideData:(NSString *)filename;

@end
